@@ -27,7 +27,8 @@ const ShapeLayerRow = new Lang.Class({
     Name: 'ShapeLayerRow',
     Extends: Gtk.ListBoxRow,
     Template: 'resource:///org/gnome/Maps/ui/shape-layer-row.ui',
-    Children: ['layerLabel', 'closeButton'],
+    Children: ['closeButton'],
+    InternalChildren: ['layerLabel', 'visibleButton'],
 
     _init: function(params) {
         this.shapeLayer = params.shapeLayer;
@@ -35,8 +36,18 @@ const ShapeLayerRow = new Lang.Class({
 
         this.parent(params);
 
-        this.layerLabel.label = this.shapeLayer.getName();
-        this.layerLabel.tooltip_text = this.shapeLayer.file.get_parse_name();
+        this._layerLabel.label = this.shapeLayer.getName();
+        this._layerLabel.tooltip_text = this.shapeLayer.file.get_parse_name();
+        this._visibleButton.connect('clicked', (function() {
+            let image = this._visibleButton.get_child();
+
+            this.shapeLayer.visible = !this.shapeLayer.visible;
+            this.activatable = this.shapeLayer.visible;
+            if (this.shapeLayer.visible)
+                image.icon_name = 'layer-visible-symbolic';
+            else
+                image.icon_name = 'layer-not-visible-symbolic';
+        }).bind(this));
     }
 });
 
@@ -47,10 +58,16 @@ const ShapeLayerFileChooser = new Lang.Class({
 
     _init: function(params) {
         this.parent(params);
+        let allFilter = new Gtk.FileFilter();
+        allFilter.set_name(_("All Layer Files"));
+        this.add_filter(allFilter);
+        this.set_filter(allFilter);
 
         ShapeLayer.SUPPORTED_TYPES.forEach((function(layerClass) {
             let filter = new Gtk.FileFilter();
-            layerClass.mimeTypes.forEach(filter.add_mime_type.bind(filter));
+            [filter, allFilter].forEach(function(f) {
+                layerClass.mimeTypes.forEach(f.add_mime_type.bind(f));
+            });
             filter.set_name(layerClass.displayName);
             this.add_filter(filter);
         }).bind(this));
@@ -60,48 +77,44 @@ const ShapeLayerFileChooser = new Lang.Class({
 const LayersPopover = new Lang.Class({
     Name: 'LayersPopover',
     Extends: Gtk.Popover,
+    Template: 'resource:///org/gnome/Maps/ui/layers-popover.ui',
+    InternalChildren: [ 'streetLayerButton',
+                        'aerialLayerButton',
+                        'layersListBox',
+                        'loadLayerButton' ],
 
     _init: function(params) {
         this._mapView = params.mapView;
         delete params.mapView;
 
-        this.ui = Utils.getUIObject('layers-popover',
-                                    [ 'grid',
-                                      'street-layer-button',
-                                      'aerial-layer-button',
-                                      'layers-list-box',
-                                      'layers-list-box-frame',
-                                      'load-layer-button' ]);
-
         this.parent({ width_request: 200,
                       no_show_all: true,
                       transitions_enabled: false,
                       visible: false });
 
-        this.ui.aerialLayerButton.join_group(this.ui.streetLayerButton);
+        this._aerialLayerButton.join_group(this._streetLayerButton);
 
         this.get_style_context().add_class('maps-popover');
-        this.add(this.ui.grid);
 
-        this.ui.layersListBox.bind_model(this._mapView.shapeLayerStore,
+        this._layersListBox.bind_model(this._mapView.shapeLayerStore,
                                          this._listBoxCreateWidget.bind(this));
-        this.ui.layersListBox.connect('row-activated', (function(lb, row) {
+        this._layersListBox.connect('row-activated', (function(lb, row) {
             this._mapView.gotoBBox(row.shapeLayer.bbox);
         }).bind(this));
 
-        this.ui.layersListBox.set_header_func(function(row, before) {
+        this._layersListBox.set_header_func(function(row, before) {
             let header = before ? new Gtk.Separator() : null;
             row.set_header(header);
         });
 
-        this.ui.loadLayerButton.connect('clicked',
-                                        this._onLoadLayerClicked.bind(this));
+        this._loadLayerButton.connect('clicked',
+                                      this._onLoadLayerClicked.bind(this));
     },
 
     _onRemoveClicked: function(row, button) {
         this._mapView.removeShapeLayer(row.shapeLayer);
-        if (this.ui.layersListBox.get_children().length <= 0)
-            this.ui.layersListBoxFrame.hide();
+        if (this._layersListBox.get_children().length <= 0)
+            this._layersListBox.hide();
     },
 
     _onLoadLayerClicked: function(button) {
@@ -109,18 +122,19 @@ const LayersPopover = new Lang.Class({
             transient_for: this.get_parent(),
         });
 
-        if (fileChooser.run() === Gtk.ResponseType.OK)
+        if (fileChooser.run() === Gtk.ResponseType.OK) {
             this._mapView.openShapeLayers(fileChooser.get_files());
+            this.hide();
+        }
 
         fileChooser.destroy();
-        this.hide();
     },
 
     _listBoxCreateWidget: function(shapeLayer) {
         let row = new ShapeLayerRow({ shapeLayer: shapeLayer });
         row.closeButton.connect('clicked',
                                 this._onRemoveClicked.bind(this, row));
-        this.ui.layersListBoxFrame.show();
+        this._layersListBox.show();
         return row;
     }
 });
