@@ -38,6 +38,7 @@ const LocationServiceNotification = imports.locationServiceNotification;
 const MapView = imports.mapView;
 const PlaceEntry = imports.placeEntry;
 const PlaceStore = imports.placeStore;
+const PrintOperation = imports.printOperation;
 const Sidebar = imports.sidebar;
 const Utils = imports.utils;
 const ZoomControl = imports.zoomControl;
@@ -57,7 +58,8 @@ const MainWindow = new Lang.Class({
                         'gotoUserLocationButton',
                         'toggleSidebarButton',
                         'layersButton',
-                        'favoritesButton' ],
+                        'favoritesButton',
+                        'printRouteButton' ],
 
     get mapView() {
         return this._mapView;
@@ -67,18 +69,13 @@ const MainWindow = new Lang.Class({
         this._overlay = params.overlay;
         delete params.overlay;
 
-        let opening = params.opening;
-        delete params.opening;
-
         this.parent(params);
 
         this._configureId = 0;
 
         this._mapView = new MapView.MapView({
             mapType: this.application.local_tile_path ?
-                MapView.MapType.LOCAL : MapView.MapType.STREET,
-            opening: opening
-        });
+                MapView.MapType.LOCAL : MapView.MapType.STREET });
 
         this._overlay.add(this._mapView);
 
@@ -123,7 +120,7 @@ const MainWindow = new Lang.Class({
                                                    });
         placeEntry.connect('notify::place', (function() {
             if (placeEntry.place) {
-                this._mapView.showSearchResult(placeEntry.place, true);
+                this._mapView.showPlace(placeEntry.place, true);
             }
         }).bind(this));
 
@@ -200,9 +197,17 @@ const MainWindow = new Lang.Class({
                 accels: ['minus', '<Primary>minus', 'KP_Subtract', '<Primary>KP_Subtract'],
                 onActivate:  this._mapView.view.zoom_out.bind(this._mapView.view)
             },
+            'toggle-scale': {
+                accels: ['<Primary>S'],
+                onActivate:  this._mapView.toggleScale.bind(this._mapView)
+            },
             'find': {
                 accels: ['<Primary>F'],
                 onActivate: this._placeEntry.grab_focus.bind(this._placeEntry)
+            },
+            'print-route': {
+                accels: ['<Primary>P'],
+                onActivate: this._printRouteActivate.bind(this)
             }
         });
     },
@@ -249,6 +254,9 @@ const MainWindow = new Lang.Class({
             this._favoritesButton.sensitive = favoritesPopover.rows > 0;
         }).bind(this));
 
+        this._mapView.bind_property('routeVisible', this._printRouteButton,
+                                    'visible', GObject.BindingFlags.DEFAULT);
+
         Application.geoclue.connect('notify::state',
                                     this._updateLocationSensitivity.bind(this));
         this.application.connect('notify::connected', (function() {
@@ -260,6 +268,7 @@ const MainWindow = new Lang.Class({
             this._favoritesButton.sensitive = (app.connected &&
                                                favoritesPopover.rows > 0);
             this._placeEntry.sensitive = app.connected;
+            this._printRouteButton.sensitive = app.connected;
         }).bind(this));
     },
 
@@ -366,6 +375,12 @@ const MainWindow = new Lang.Class({
         }
     },
 
+    _printRouteActivate: function() {
+        if (this._mapView.routeVisible) {
+            let operation = new PrintOperation.PrintOperation({ mainWindow: this });
+        }
+    },
+
     _onMapTypeMenuActivate: function(action) {
         let state = action.get_state().get_boolean();
         action.set_state(GLib.Variant.new('b', !state));
@@ -404,7 +419,7 @@ const MainWindow = new Lang.Class({
                        ' 2011' + String.fromCharCode(0x2013) +
                        '2013 Red Hat, Inc.',
             license_type: Gtk.License.GPL_2_0,
-            logo_icon_name: 'gnome-maps',
+            logo_icon_name: 'org.gnome.Maps',
             version: pkg.version,
             website: 'https://live.gnome.org/Apps/Maps',
             wrap_license: true,
