@@ -23,7 +23,6 @@ const Champlain = imports.gi.Champlain;
 const Clutter = imports.gi.Clutter;
 const GObject = imports.gi.GObject;
 const Geocode = imports.gi.GeocodeGlib;
-const gettext = imports.gettext;
 const Gio = imports.gi.Gio;
 const GtkChamplain = imports.gi.GtkChamplain;
 const Lang = imports.lang;
@@ -33,6 +32,8 @@ const Application = imports.application;
 const ContactPlace = imports.contactPlace;
 const Geoclue = imports.geoclue;
 const GeoJSONShapeLayer = imports.geoJSONShapeLayer;
+const KmlShapeLayer = imports.kmlShapeLayer;
+const GpxShapeLayer = imports.gpxShapeLayer;
 const Location = imports.location;
 const Maps = imports.gi.GnomeMaps;
 const MapWalker = imports.mapWalker;
@@ -84,7 +85,7 @@ const MapView = new Lang.Class({
         let mapType = params.mapType || MapType.STREET;
         delete params.mapType;
 
-        this.view = this._initView(params.opening);
+        this.view = this._initView();
         this._initLayers();
 
         this._factory = Champlain.MapSourceFactory.dup_default();
@@ -101,7 +102,23 @@ const MapView = new Lang.Class({
         this._connectRouteSignals();
     },
 
-    _initView: function(opening) {
+    _initScale: function(view) {
+        this._scale = new Champlain.Scale({ visible: true });
+        this._scale.connect_view(view);
+
+        if (Utils.getMeasurementSystem() === Utils.METRIC_SYSTEM)
+            this._scale.unit = Champlain.Unit.KM;
+        else
+            this._scale.unit = Champlain.Unit.MILES;
+
+        this._scale.set_x_expand(true);
+        this._scale.set_y_expand(true);
+        this._scale.set_x_align(Clutter.ActorAlign.START);
+        this._scale.set_y_align(Clutter.ActorAlign.END);
+        view.add_child(this._scale);
+    },
+
+    _initView: function() {
         let view = this.get_view();
         view.zoom_level = 3;
         view.min_zoom_level = MapMinZoom;
@@ -109,7 +126,7 @@ const MapView = new Lang.Class({
         view.reactive = true;
         view.kinetic_mode = true;
 
-        if (!opening)
+        if (Application.normalStartup)
             view.connect('notify::realized', this._goToStoredLocation.bind(this));
         view.connect('notify::latitude', this._onViewMoved.bind(this));
         // switching map type will set view min-zoom-level from map source
@@ -118,14 +135,16 @@ const MapView = new Lang.Class({
                 view.min_zoom_level = MapMinZoom;
             }
         }).bind(this));
+
+        this._initScale(view);
         return view;
     },
 
     _initLayers: function() {
         let strokeColor = new Clutter.Color({ red: 0,
-                                               blue: 255,
-                                               green: 0,
-                                               alpha: 100 });
+                                              blue: 255,
+                                              green: 0,
+                                              alpha: 100 });
 
         let mode = Champlain.SelectionMode.SINGLE;
 
@@ -147,6 +166,8 @@ const MapView = new Lang.Class({
         this.view.add_layer(this._annotationMarkerLayer);
 
         ShapeLayer.SUPPORTED_TYPES.push(GeoJSONShapeLayer.GeoJSONShapeLayer);
+        ShapeLayer.SUPPORTED_TYPES.push(KmlShapeLayer.KmlShapeLayer);
+        ShapeLayer.SUPPORTED_TYPES.push(GpxShapeLayer.GpxShapeLayer);
     },
 
     _connectRouteSignals: function() {
@@ -199,6 +220,10 @@ const MapView = new Lang.Class({
         }).bind(this));
     },
 
+    toggleScale: function() {
+        this._scale.visible = !this._scale.visible;
+    },
+
     openShapeLayers: function(files) {
         let bbox = new Champlain.BoundingBox();
         let ret = true;
@@ -393,7 +418,7 @@ const MapView = new Lang.Class({
         route.reset();
     },
 
-    showSearchResult: function(place, animation) {
+    showPlace: function(place, animation) {
         this._placeLayer.remove_all();
 
         if (place instanceof StoredRoute.StoredRoute) {
