@@ -28,6 +28,8 @@ const Rest = imports.gi.Rest;
 const Secret = imports.gi.Secret;
 const Soup = imports.gi.Soup;
 
+const Utils = imports.utils;
+
 const BASE_URL = 'https://api.openstreetmap.org/api';
 const API_VERSION = '0.6';
 
@@ -90,7 +92,7 @@ const OSMConnection = new Lang.Class({
            OAuth access token enrolled, so, if the currently instanciated
            proxy instance doesn't have a token set, we could safely count on
            it being present in the keyring */
-        if (this._oauthProxy.get_token() === null) {
+        if (this._callProxy.get_token() === null) {
             Secret.password_lookup(SECRET_SCHEMA, {}, null, function(s, res) {
                 this._onPasswordLookedUp(res,
                                          comment,
@@ -231,6 +233,7 @@ const OSMConnection = new Lang.Class({
 
     _onRequestOAuthToken: function(error, callback) {
         if (error) {
+            Utils.debug(error);
             callback(false);
             return;
         }
