@@ -36,12 +36,21 @@ const Place = new Lang.Class({
         this._population = params.population;
         delete params.population;
 
+        this._website = params.website;
+        delete params.website;
+
+        this._phone = params.phone;
+        delete params.phone;
+
         this._wiki = params.wiki;
         delete params.wiki;
 
         this._openingHours = params.openingHours;
         delete params.openingHours;
 
+        this._internetAccess = params.internetAccess;
+        delete params.internetAccess;
+
         /* Determines if the place should be added to the place store */
         if (typeof(params.store) === 'undefined') {
             this._store = true;
@@ -100,6 +109,22 @@ const Place = new Lang.Class({
         return this._population;
     },
 
+    set website(v) {
+        this._website = v;
+    },
+
+    get website() {
+        return this._website;
+    },
+
+    set phone(v) {
+        this._phone = v;
+    },
+
+    get phone() {
+        return this._phone;
+    },
+
     set wiki(v) {
         this._wiki = v;
     },
@@ -116,10 +141,22 @@ const Place = new Lang.Class({
         return this._openingHours;
     },
 
+    set internetAccess(v) {
+        this._internetAccess = v;
+    },
+
     get openingHoursTranslated() {
         return Translations.translateOpeningHours(this._openingHours);
     },
 
+    get internetAccess() {
+        return this._internetAccess;
+    },
+
+    get internetAccessTranslated() {
+        return Translations.translateInternetAccess(this._internetAccess);
+    },
+
     set wheelchair(v) {
         this._wheelchair = v;
     },
@@ -181,6 +218,7 @@ const Place = new Lang.Class({
 
         return { id: this.osm_id,
                  osm_type: this.osm_type,
+                 place_type: this.place_type,
                  name: this.name,
                  bounding_box: bounding_box,
                  this_type: this.this_type,
@@ -197,9 +235,12 @@ const Place = new Lang.Class({
                  country_code: this.contry_code,
                  continent: this.continent,
                  population: this.population,
+                 website: this.website,
+                 phone: this.phone,
                  wiki: this.wiki,
                  wheelchair: this.wheelchair,
-                 openingHours: this.openingHours };
+                 openingHours: this.openingHours,
+                 internetAccess: this.internetAccess };
     },
 
     match: function(searchString) {
@@ -269,4 +310,4 @@ Place.parseCoordinates = function(text) {
             return null;
     } else
         return null;
-};
\ No newline at end of file
+};
